diff --git a/js/commerce_square.form.js b/js/commerce_square.form.js
index 5aaa65c..04072b5 100644
--- a/js/commerce_square.form.js
+++ b/js/commerce_square.form.js
@@ -140,15 +140,18 @@
     // This function is called when a buyer clicks the Submit button on the webpage
     // to charge their card.
     function requestCardNonce(event) {
-      // This prevents the Submit button from submitting its associated form.
-      // Instead, clicking the Submit button should tell the SqPaymentForm to generate
-      // a card nonce, which the next line does.
-      event.preventDefault();
+      // Make sure the Commerce Square Payment method is selected before hijacking the Submit button.
+      if ($('#edit-commerce-payment-payment-method-commerce-squarecommerce-payment-commerce-square').is(':checked') === true) {
+        // This prevents the Submit button from submitting its associated form.
+        // Instead, clicking the Submit button should tell the SqPaymentForm to generate
+        // a card nonce, which the next line does.
+        event.preventDefault();
 
-      // Grab postal code.
-      paymentForm.setPostalCode($parentDrupalSelector.parent().find('input.postal-code').val());
+        // Grab postal code.
+        paymentForm.setPostalCode($parentDrupalSelector.parent().find('input.postal-code').val());
 
-      commerceSquare.getPaymentForm().requestCardNonce();
+        commerceSquare.getPaymentForm().requestCardNonce();
+      }
     }
 
     /**
